==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/ValNode.h <==
// public class soot.jimple.spark.pag.ValNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_Node

#include "soot/jimple/spark/pag/Node.h"

#ifndef _JC_soot_jimple_spark_pag_ValNode_H_
#define _JC_soot_jimple_spark_pag_ValNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ValNode$sub_refs	_jc_soot_jimple_spark_pag_ValNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	_jc_soot_jimple_spark_pag_ValNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$refs	_jc_soot_jimple_spark_pag_ValNode$refs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$nonrefs	_jc_soot_jimple_spark_pag_ValNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$object	_jc_soot_jimple_spark_pag_ValNode$object;

typedef const struct _jc_soot_jimple_spark_pag_ValNode$vmethods	_jc_soot_jimple_spark_pag_ValNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ValNode$vtable	_jc_soot_jimple_spark_pag_ValNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ValNode$vtype	_jc_soot_jimple_spark_pag_ValNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ValNode$method$_init$19cf15175ba61f2d(_jc_env *, struct _jc_soot_jimple_spark_pag_ValNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_Type$object *);

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ValNode$vmethods {
};

// Vtable
struct _jc_soot_jimple_spark_pag_ValNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ValNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ValNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ValNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ValNode$refs {
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ValNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ValNode$object {
	_jc_soot_jimple_spark_pag_ValNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ValNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ValNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ValNode$vtype _jc_soot_jimple_spark_pag_ValNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ValNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ValNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ValNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/ValNode.h <==
// public class soot.jimple.spark.pag.ValNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node
// @dep_class 8f994f8885f1a8b4 soot_jimple_spark_pag_ValNode

// header file dependencies
// @dep_header soot_jimple_spark_pag_Node

#include "soot/jimple/spark/pag/Node.h"

#ifndef _JC_soot_jimple_spark_pag_ValNode_H_
#define _JC_soot_jimple_spark_pag_ValNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_ValNode$sub_refs	_jc_soot_jimple_spark_pag_ValNode$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	_jc_soot_jimple_spark_pag_ValNode$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$refs	_jc_soot_jimple_spark_pag_ValNode$refs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$nonrefs	_jc_soot_jimple_spark_pag_ValNode$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_ValNode$object	_jc_soot_jimple_spark_pag_ValNode$object;

typedef const struct _jc_soot_jimple_spark_pag_ValNode$vmethods	_jc_soot_jimple_spark_pag_ValNode$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_ValNode$vtable	_jc_soot_jimple_spark_pag_ValNode$vtable;
typedef const struct _jc_soot_jimple_spark_pag_ValNode$vtype	_jc_soot_jimple_spark_pag_ValNode$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_ValNode$method$_init$19cf15175ba61f2d(_jc_env *, struct _jc_soot_jimple_spark_pag_ValNode$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_ValNode$vmethods {
};

// Vtable
struct _jc_soot_jimple_spark_pag_ValNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_ValNode$vmethods	soot_jimple_spark_pag_ValNode;
};

// Vtype
struct _jc_soot_jimple_spark_pag_ValNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_ValNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ValNode$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ValNode$refs {
    _jc_soot_jimple_spark_pag_ValNode$sub_refs	soot_jimple_spark_pag_ValNode;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_ValNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_ValNode$sub_nonrefs	soot_jimple_spark_pag_ValNode;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_ValNode$object {
	_jc_soot_jimple_spark_pag_ValNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_ValNode$vtype	*vtype;
	_jc_soot_jimple_spark_pag_ValNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_ValNode$vtype _jc_soot_jimple_spark_pag_ValNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_ValNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_ValNode$class_object;

#endif	/* _JC_soot_jimple_spark_pag_ValNode_H_ */
